@@ -1,15 +1,16 @@
 import tensorflow
 
+from dbnd_tensorflow.seven import History, models
 from targets.values.builtins_values import DataValueType
 
 
 class TensorflowModelValueType(DataValueType):
-    type = tensorflow.keras.models.Model
+    type = models.Model
     type_str = "Model"
     config_name = "tensorflow_model"
 
 
 class TensorflowHistoryValueType(DataValueType):
-    type = tensorflow.python.keras.callbacks.History
+    type = History
     type_str = "History"
     config_name = "tensorflow_history"
